@@ -1,4 +1,5 @@
-subroutine iricore(jf, jmag, glat, glon, gsize, iyyyy, mmdd, dhour, heibeg, heiend, heistp, oarr, iri_res, datadir, ddsize)
+subroutine iricore(jf, jmag, glat, glon, gsize, iyyyy, mmdd, dhour, heibeg, heiend, heistp, oarr, iri_res, datadir, &
+                   ddsize, aap_, af107_, n_)
   logical, intent(in) :: jf(50)
   logical, intent(in) :: jmag
   integer, intent(in) :: gsize
@@ -9,16 +10,26 @@ subroutine iricore(jf, jmag, glat, glon, gsize, iyyyy, mmdd, dhour, heibeg, heie
   real, intent(inout) :: iri_res(20, 1000, gsize)
   integer, intent(in) :: ddsize
   character(ddsize), intent(in) :: datadir
+  integer, intent(in) :: aap_(27000, 9)
+  real, intent(in) :: af107_(27000, 3)
+  integer, intent(in) :: n_
 
+  integer :: aap(27000, 9)
+  real :: af107(27000, 3)
+  integer :: n
+  common /apfa/aap, af107, n
   real :: outf(20,1000)
   character(256) :: datadir1
   common /folders/ datadir1
   integer :: i, k, j
   integer :: NITER
 
+  aap = aap_
+  af107 = af107_
+  n = n_
   datadir1 = datadir
   call read_ig_rz
-  call readapf107
+!  call readapf107
   NITER = SIZE(glat)
 
 
